*********************************
*** ENDLINE DATA AND ANALYSIS *** 
*********************************

* Global macros

global QJPSfigures "/Users/zhaosongruan/Desktop/20045/figures"
global QJPSendline "/Users/zhaosongruan/Desktop/20045/endline"
global QJPSdofiles "/Users/zhaosongruan/Desktop/20045/do_files"
global QJPStables "/Users/zhaosongruan/Desktop/20045/tables"
global QJPSreplication "/Users/zhaosongruan/Desktop/20045"

cd "$QJPSendline"
use endline.dta, clear

* Main reasons for switching halls
tab q29 if q29!=.a & q29!=.b & inlist(q26,1,3,4,5), m
* Main reasons for switching halls among non-compliers
tab q29 if q29!=1 & q29!=.a & q29!=.b, m
* Main reasons for switching among government students
tab q29 if q29!=.a & q29!=.b & inlist(q26,1,3,4,5) & q11==0, m

*ssc install tabout
* Get numbers for descriptive table and totals for each column
gen halltotal = hallresp / hallresprate * 100
table qa, c(m halltotal m hallresp m hallresprate m hallcomp m hallcomprate) ///
format(%9.0f) center
sum hallresp if qa!=. // 3381
di 3381/3995*100 // 84.631
tab comp if qa!=. // 2681
sum hallcomprate if qa!=. // 79.296

gen revq11 = q11 
revrs revq11, replace
replace revq11 = revq11 - 1 
tab revq11, m // 1328 govt students
bysort qa: tab revq11 // for raw number of gov students per hall
bysort qa: sum revq11 // for % of gov students per hall
bysort revq11: tab comp // % compliers by private vs. govt students
bysort qa: tab comp if revq11==1 // % compliers/hall for govt students 
tab comp if revq11==1 // mean compliance for govt students  

drop if inlist(qa,2,6,7,8,9)
* Get numbers for descriptive table and totals for each column
table qa, c(m hallresp m hallresprate m hallcomp m hallcomprate) ///
format(%9.0f) center
* total is 1733 taken from hall_admission_numbers
di 1490/1733*100 // 85.98
tab comp // 2681
di 1187/1490*100 // 79.66

bysort revq11: tab comp // % compliers by private vs. govt students
drop if hall == ""
*table hall, c(m nm) format(%9.0f) center 
estpost tabstat hallresidents nm, by(hall) statistics(sum)

drop if nm == 1 // behavioral game participants that we could not match to survey participants

* restrict analysis to compliers
drop if comp == 0 | comp == . 

* Table A.23
tab1 name_missing regno_missing phoneno1_missing if q28male==3
tab1 name_missing regno_missing phoneno1_missing if q28male==4
tab1 name_missing regno_missing phoneno1_missing if q28fem==1
tab1 name_missing regno_missing phoneno1_missing if q28fem==5


*******************************************************
*********** MODELS AND GRAPHS FOR PAPER ***************
*******************************************************

clear all
eststo clear 
qui do "$QJPSdofiles/endline_setup.do" // includes use endline.dta
qui do "$QJPSdofiles/models_in1column_v2.do"


** Controls macros
global esttabformat obs b(%8.2f) p(%8.2f) ar2(%8.2f) r2(%8.2f) star(+ 0.10 * 0.05 ** 0.01)


global controls q2 q6 q7 q9* q12new q14_1 q14_2 region_1 region_2 region_4 
global controlsgov "q2 q6 q7 q9* q12new q14_1 q14_2 region_1 region_2 region_4 if q11==0 & q8<5"
global controlsgovnoq9 "q2 q6 q7 q12new q14_1 q14_2 region_1 region_2 region_4 if q11==0 & q8<5"
global controlsgames "q2 q6 q7 q9* q12new q14_1 q14_2 region_1 region_2 region_4 if q8<5"
macro dir

** Balance tables for govt students
label var q2 "Age"
label var q6 "Father education"
label var q7 "Mother education"
label var q9a "Family car ownership"
label var q9b "Family motorbike ownership"
label var q9c "Family computer ownership"
label var q9d "Family generator ownership"
label var q12new "A-levels score"
label var q13_1 "Agricultural and Environmental Sciences"
label var q13_9 "Veterinary Medicine and Animal Resources"


* Tables A.29-A.32
cd "$QJPStables"
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balance_lum2gov.tex if q11==0 & q8<5, by(lum2) latex stars pcompare replace /// pcompare 
count armlabel(Livingstone Lumumba)
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balance_lum2.tex if q8<5, by(lum2) latex stars pcompare replace /// pcompare 
count armlabel(Livingstone Lumumba)
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balance_ms2gov.tex if q11==0 & q8<5, by(ms2) latex stars pcompare replace /// pcompare 
count armlabel(Africa "Mary Stuart")
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balance_ms2.tex if q8<5, by(ms2) latex stars pcompare replace /// pcompare 
count armlabel(Africa "Mary Stuart")

* Balance tables for behavioral games (All students - actually more balanced if 
* we include all students as opposed to only govt perhaps because of larger sample 
* prevents small sample imbalances. 

cd "$QJPStables"
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balancegames_lum2gov.tex if q8<5 & partingames==1, by(lum2) latex stars pcompare replace /// pcompare 
count armlabel(Livingstone Lumumba)
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balancegames_ms2gov.tex if q8<5 & partingames==1, by(ms2) latex stars pcompare replace /// pcompare 
count armlabel(Africa "Mary Stuart")

* Interaction with leadership
gen lum2xq61 = lum2*q61
label var lum2xq61 "Lumumba leadership" 
gen ms2xq61 = ms2*q61
label var ms2xq61 "Mary Stuart leadership" 

* Interaction controls
gen q2xq12new = q2*q12new
gen q2xq14_1 = q2*q14_1
gen q12newxq14_1 = q12new*q14_1


** TRUST ** 

foreach x in a a2 b c d e {
qui eststo q37`x'_lum2: reg q37`x' lum2 $controlsgov
qui eststo q37`x'_ms2: reg q37`x' ms2 $controlsgov
}
qui eststo q25stud_lum2: reg q25stud lum2 $controlsgov
qui eststo q25stud_ms2: reg q25stud ms2 $controlsgov

cd "$QJPStables"
foreach var of varlist lum2 ms2 {
esttab q37a_`var' q37a2_`var' q37b_`var' q37c_`var' q37d_`var' q37e_`var' /// q25stud_`var' /// 
q25stud_`var' using trust`var'gov.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall\\residents}" "\shortstack{Partner\\hall}" "\shortstack{Makerere\\students}" "\shortstack{Makerere\\police force}" ///
"\shortstack{Dean of\\Students}" "\shortstack{Vice-\\Chancellor}" "\shortstack{Academic\\misconduct}") /// 
refcat(`var' "", nolabel) nogaps keep(`var') order(`var') 
}

* Trust regression output with merged coeffs

foreach var of varlist q37a q37a2 q37b q37c q37d q37e q25stud{
mergemodels `var'_lum2 `var'_ms2 
eststo `var'_lumms
estadd local N = "`e(`var'_lum2_N)'/`e(`var'_ms2_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2_R2)'/`:di %3.2f e(`var'_ms2_R2)'"
}

cd "$QJPStables"
esttab q37a_lumms q37a2_lumms q37b_lumms q37c_lumms q37d_lumms ///
q37e_lumms q25stud_lumms using trust_lummsgov.tex, ///
replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall\\residents}" "\shortstack{Partner\\hall}" "\shortstack{Makerere\\students}" "\shortstack{Makerere\\police force}" ///
"\shortstack{Dean of\\Students}" "\shortstack{Vice-\\Chancellor}" "\shortstack{Academic\\misconduct}") /// 
indicate("Controls = q2") nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 

** TRUST WITHOUT CONTROLS ** 

foreach x in a a2 b c d e {
qui eststo q37`x'_lum2noctrl: reg q37`x' lum2 if q11==0 & q8<5 
qui eststo q37`x'_ms2noctrl: reg q37`x' ms2 if q11==0 & q8<5 
}
qui eststo q25stud_lum2noctrl: reg q25stud lum2 if q11==0 & q8<5 
qui eststo q25stud_ms2noctrl: reg q25stud ms2 if q11==0 & q8<5 

* Trust regression output with merged coeffs NO CONTROLS

foreach var of varlist q37a q37a2 q37b q37c q37d q37e q25stud{
mergemodels `var'_lum2noctrl `var'_ms2noctrl 
eststo `var'_lummsnoctrl
estadd local N = "`e(`var'_lum2noctrl_N)'/`e(`var'_ms2noctrl_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2noctrl_R2)'/`:di %3.2f e(`var'_ms2noctrl_R2)'"
}

cd "$QJPStables"
esttab q37a_lummsnoctrl q37a2_lummsnoctrl q37b_lummsnoctrl q37c_lummsnoctrl q37d_lummsnoctrl ///
q37e_lummsnoctrl q25stud_lummsnoctrl using trust_lummsgovnoctrl.tex, ///
replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall\\residents}" "\shortstack{Partner\\hall}" "\shortstack{Makerere\\students}" "\shortstack{Makerere\\police force}" ///
"\shortstack{Dean of\\Students}" "\shortstack{Vice-\\Chancellor}" "\shortstack{Academic\\misconduct}") /// 
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 
*Add Controls row to table manually - since no control in any regression indicate() doesn't work


* Trust interacted with leadership 

foreach x in a a2 b c d e {
qui eststo q37`x'_lum2q61gov: reg q37`x' lum2 q61 lum2xq61 $controlsgov
qui eststo q37`x'_ms2q61gov: reg q37`x' ms2 q61 ms2xq61 $controlsgov
}
qui eststo q25stud_lum2q61gov: reg q25stud lum2 q61 lum2xq61 $controlsgov
qui eststo q25stud_ms2q61gov: reg q25stud ms2 q61 ms2xq61 $controlsgov

esttab q37*lum2q61gov q25stud_lum2q61gov, keep(lum2* q61) $esttabformatse
esttab q37*ms2q61gov q25stud_ms2q61gov, keep(ms2* q61) $esttabformatse

preserve
cd "$QJPStables"
label var q61 "Leadership role indicator"
esttab q37a_lum2q61gov q37b_lum2q61gov q37c_lum2q61gov q37d_lum2q61gov q37e_lum2q61gov q25stud_lum2q61gov using trust_lum2q61gov.tex, ///
replace label varlabels(, elist(ms2 \hline)) ///
stats(N r2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall\\residents}" "\shortstack{Partner\\hall}" "\shortstack{Makerere\\students}" "\shortstack{Makerere\\police force}" ///
"\shortstack{Dean of\\Students}" "\shortstack{Vice-\\Chancellor}" "\shortstack{Academic\\misconduct}") /// 
indicate("Controls = q2") nogaps keep(lum2 q61 lum2xq61) order(lum2 q61 lum2xq61) // refcat(lum2 "", nolabel) 
restore


* Academic regressions 

foreach var of varlist q19new q20 q22 q23 q24new {
foreach x in lum ms {
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Academic regressions - regression output with merged coeffs

foreach var of varlist q19new q20 q22 q23 q24new{
mergemodels `var'_lum2gov `var'_ms2gov 
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

* acad behavior and reputations combined
cd "$QJPStables"
esttab q19new_lummsgov q20_lummsgov q24new_lummsgov q22_lummsgov q23_lummsgov /// 
using acad_all_lumms.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)"))  ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Grades (CGPA)}" "\shortstack{Class participation}" ///
"\shortstack{Sharing notes}" "\shortstack{Hallmates\\noisy in class}" ///
"\shortstack{Hallmates\\study hard}") indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


* Campus activism

foreach var of varlist q38*new {
foreach x in lum ms {
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Campus activism regressions - regression output with merged coeffs

foreach var of varlist q38anew q38bnew q38cnew{
mergemodels `var'_lum2gov `var'_ms2gov 
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab q38anew_lummsgov q38bnew_lummsgov q38cnew_lummsgov /// 
using activism_lummsgov.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Sign\\a petition}" "\shortstack{Attend\\a demonstration}" ///
"\shortstack{Join\\a strike}") indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 

* Politics

foreach var of varlist q51 q55a q55b q55c {
foreach x in lum ms {
*eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

foreach var of varlist q51 q55a q55b q55c{
mergemodels `var'_lum2gov `var'_ms2gov 
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab q51_lummsgov q55a_lummsgov q55b_lummsgov q55c_lummsgov /// 
using politics_lummsgov.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Interest in\\Ugandan politics}" "\shortstack{Approval of\\Uganda's President}" ///
"\shortstack{Approval of\\ruling party}" "\shortstack{Approval of\\opposition party}") indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


* Social practices and habits

foreach var of varlist q39_1 q39_2 q39_3 q40new2 {
foreach x in lum ms {
*eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

foreach var of varlist q39_1 q39_2 q39_3 q40new2{
mergemodels `var'_lum2gov `var'_ms2gov 
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab q39_1_lummsgov q39_2_lummsgov q39_3_lummsgov q40new2_lummsgov /// 
using social_lummsgov.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Religious\\association}" "\shortstack{Ethnic\\association}" ///
"\shortstack{Hall\\association}" "\shortstack{Number of\\clubs/associations}") indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 



** TIME PREFERENCES ** 

foreach var of varlist q32 q33 {
foreach x in lum ms {
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Time preferences regression output with merged coeffs

foreach var of varlist q32 q33{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

** IDENTITY ** 

qui eststo q64_lum2: reg q64 lum2 $controls
qui eststo q64_lum2gov: reg q64 lum2 $controlsgov
qui eststo q64_ms2: reg q64 ms2 $controls
qui eststo q64_ms2gov: reg q64 ms2 $controlsgov
qui eststo q18_lum2: reg q18 lum2 $controls
qui eststo q18_lum2gov: reg q18 lum2 $controlsgov
qui eststo q18_ms2: reg q18 ms2 $controls
qui eststo q18_ms2gov: reg q18 ms2 $controlsgov

* Identity regression output with merged coeffs

foreach var of varlist q64 q18{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

* Identity and time preferences in one table
cd "$QJPStables"
esttab q64_lummsgov q18_lummsgov q32_lummsgov q33_lummsgov ///
using identity_timedisc_lummsgov.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall identity}" "\shortstack{Ethnic identity}" ///
"\shortstack{Now vs. in 1 week}" "\shortstack{Now vs. in 1 month}") /// 
indicate("Controls = q2") ///
eqlabels(none) nogaps nonotes keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "" ms2 "", nolabel) 

* Identity and time preferences interacted with leadership 
eststo q64_lum2q61: reg q64 lum2 q61 lum2xq61 $controls
eststo q64_lum2q61gov: reg q64 lum2 q61 lum2xq61 $controlsgov
eststo q64_ms2q61: reg q64 ms2 q61 ms2xq61 $controls
eststo q64_ms2q61gov: reg q64 ms2 q61 ms2xq61 $controlsgov
eststo q18_lum2q61: reg q18 lum2 q61 lum2xq61 $controls
eststo q18_lum2q61gov: reg q18 lum2 q61 lum2xq61 $controlsgov
eststo q18_ms2q61: reg q18 ms2 q61 ms2xq61 $controls
eststo q18_ms2q61gov: reg q18 ms2 q61 ms2xq61 $controlsgov

esttab q64_lum2q61* q18_lum2q61*, keep(lum2* q61) $esttabformatse
esttab q64_ms2q61* q18_ms2q61*, keep(ms2* q61) $esttabformatse
bysort q61: sum q64 if inlist(lum2, 0, 1)
bysort q61: sum q64 if inlist(ms2, 0, 1)

foreach var of varlist q32 q33 {
qui eststo `var'_lum2q61: reg `var' lum2 q61 lum2xq61 $controls
qui eststo `var'_ms2q61: reg `var' ms2 q61 ms2xq61 $controls
qui eststo `var'_lum2q61gov: reg `var' lum2 q61 lum2xq61 $controlsgov // probit
qui eststo `var'_ms2q61gov: reg `var' ms2 q61 ms2xq61 $controlsgov // probit
}

esttab q32_lum2q61* q33_lum2q61*, keep(lum2* q61) $esttabformatse
esttab q32_ms2q61* q33_ms2q61*, keep(ms2* q61) $esttabformatse
bysort q61: sum q32 if inlist(lum2, 0, 1)
bysort q61: sum q32 if inlist(ms2, 0, 1)
by lum2, sort : ttest q32, by(q61)

* Identity and time preferences in one table: interaction with leadership indicator
cd "$QJPStables"
label var q61 "Leadership role indicator"
esttab q64_lum2q61gov q18_lum2q61gov q32_lum2q61gov q33_lum2q61gov using identity_timedisc_lum2q61gov.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N r2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hall identity}" "\shortstack{Ethnic identity}" ///
"\shortstack{Now vs. in 1 week}" "\shortstack{Now vs. in 1 month}") /// 
indicate("Controls = q2") ///
nogaps nonotes keep(lum2 q61 lum2xq61) order(lum2 q61 lum2xq61) // refcat(lum2 "" ms2 "", nolabel) eqlabels(none) 


** GENEROSITY ** 

foreach var of varlist q34_1a100 q34_2a100 {
foreach x in lum ms {
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Generosity regression output with merged coeffs

foreach var of varlist q34_1a100 q34_2a100{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

* Behavioral games results

local beh offer1 
foreach var of varlist `beh' {
foreach x in lum2 ms2 {
qui eststo `var'_`x'_hall: reg `var' `x' if inlist(cond,1,2)
qui eststo `var'_`x'_hallctrl: reg `var' `x' $controlsgames & inlist(cond,1,2)
}
}

** Generosity including survey and behavioral games

foreach x in hall hallctrl{
mergemodels offer1_lum2_`x' offer1_ms2_`x'
eststo offer1_lumms_`x'
estadd local N = "`e(offer1_lum2_`x'_N)'/`e(offer1_ms2_`x'_N)'"
estadd local R2 = "`:di %3.2f e(offer1_lum2_`x'_R2)'/`:di %3.2f e(offer1_ms2_`x'_R2)'"
}

cd "$QJPStables"
esttab q34_1a100_lummsgov q34_2a100_lummsgov offer1_lumms_hall offer1_lumms_hallctrl using generosity.tex, ///
replace label b(2) se(2) r2(2) nonotes ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)"))  varlabels(, elist(ms2 \hline)) ///
indicate("Controls = q2") star(\dag 0.10 * 0.05 ** 0.01) ///
mgroups("Survey" "Behavioral games", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
mtitles("\shortstack{Hall\\allocation}" "\shortstack{Partner hall\\allocation}" ///
"\shortstack{Offer to\\hall peer}" "\shortstack{Offer to\\hall peer}") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


** OCEAN for endline

foreach var of varlist q79_* {
foreach x in lum ms {
*eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

foreach var of varlist q79_*{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab q79_a_lummsgov q79_b_lummsgov q79_c_lummsgov q79_d_lummsgov q79_e_lummsgov /// 
using ocean_lummsgov.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Talkative}" "\shortstack{Clever}" ///
"\shortstack{Disorganized}" "\shortstack{Always\\calm}" ///
"\shortstack{Cooperative}") indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 

* Education leaflet and condoms

foreach var of varlist educ cd {
foreach x in lum ms {
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Education leaflet and condoms regressions - regression output with merged coeffs

foreach var of varlist educ cd{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab educ_lummsgov cd_lummsgov /// 
using educ_cd_lummsgov.tex, replace label b(2) se(2) r2(2) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) varlabels(, elist(ms2 \hline)) ///
mtitles("\shortstack{Education\\leaflet take up}" "\shortstack{Condom\\take up}") ///
indicate("Controls = q2") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


** MECHANISMS ** 

* do leaders across halls show higher hall involvement?

foreach var of varlist q66_a q66_b q66_c q70num {
foreach x in lum ms { 
eststo `var'_`x'2govq61: reg `var' q61 $controlsgov & inlist(`x'2,0,1)
}
}


foreach var of varlist q66_a q66_b q66_c q70num{
mergemodels `var'_lum2govq61 `var'_ms2govq61
eststo `var'_lummsgovq61
estadd local N = "`e(`var'_lum2govq61_N)'/`e(`var'_ms2govq61_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2govq61_R2)'/`:di %3.2f e(`var'_ms2govq61_R2)'"
}

preserve
label var q61 "Hall leader indicator"
cd "$QJPStables"
esttab q66_a_lummsgovq61 q66_b_lummsgovq61 q66_c_lummsgovq61 ///
q70num_lummsgovq61 using lummsgovq61.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
varlabels(, elist(q61 \hline)) stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
mtitles("\shortstack{Attending\\leadership meetings}" "\shortstack{Attending\\social events}" ///
"\shortstack{Hall\\jogging}" "\shortstack{Time spent\\in hall}") /// 
nogaps keep(q61) order(q61) indicate("Controls = q2") //refcat(lum2 "", nolabel) 
restore


* Involvement with hall, strength of culture

foreach var of varlist revq59 q60 q65new q66_b q66_c {
foreach x in lum ms { 
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

*set trace on

foreach var of varlist revq59 q60 q65new q66_b q66_c{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

* Mechanisms 
cd "$QJPStables"
esttab q65new_lummsgov q66_b_lummsgov q66_c_lummsgov revq59_lummsgov q60_lummsgov /// 
using mech1lummsgov.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Reading hall\\announcements}" "\shortstack{Attending\\social events}" ///
"\shortstack{Hall\\jogging}" "\shortstack{Strength of\\hall culture}" "\shortstack{Activity of\\hall leaders}") ///
indicate("Controls = q2") nogaps keep(lum2 ms2) order(lum2 ms2) //refcat(lum2 "", nolabel) 


* Testing competing explanations
* roommates: q30new  / time in hall: q70num / 
* hall fit: q27 / hall safety: q67new

foreach var of varlist q27 q30new q67new q70num {
foreach x in lum ms { 
qui eststo `var'_`x'2: reg `var' `x'2 $controls
qui eststo `var'_`x'2gov: reg `var' `x'2 $controlsgov
}
}

* Mech 2 regression output with merged coeffs

foreach var of varlist q27 q30new q67new q70num{
mergemodels `var'_lum2gov `var'_ms2gov
eststo `var'_lummsgov
estadd local N = "`e(`var'_lum2gov_N)'/`e(`var'_ms2gov_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2gov_R2)'/`:di %3.2f e(`var'_ms2gov_R2)'"
}

cd "$QJPStables"
esttab q27_lummsgov q30new_lummsgov q67new_lummsgov q70num_lummsgov ///
using mechnull_lummsgov.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) nonotes ///
star(\dag 0.10 * 0.05 ** 0.01) indicate("Controls = q2") ///
mtitles("\shortstack{Hall\\fit}" "\shortstack{Number of\\Roommates}" ///
"\shortstack{Theft\\in hall}" "\shortstack{Time spent\\in hall}") /// 
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 



********************************************************
** BEHAVIORAL DATA: BALANCE AND GROUP-LEVEL DONATIONS **
********************************************************

cd "$QJPSendline"
use endline.dta, clear

sort hallgames group cond

table nm partingames, m row col // 111/939 participants not matched
table nm partingames if inlist(hallgames,1,3,4,5), m row col // 111/939 participants not matched
table comp partingames if inlist(hallgames,1,3,4,5), m row col // 125/923 particiapants not compliers

* restrict analysis to compliers
drop if hallgames == .a
drop if comp == 0 

* Hall dummies
gen lum2 = 0 if inlist(q28male,3)
label var lum2 "Lumumba"
replace lum2 = 1 if q28male==4
gen ms2 = 0 if inlist(q28fem,1)
label var ms2 "Mary Stuart"
replace ms2 = 1 if q28fem==5

gen grouppot = doubledgrouppot / 2
order grouppot, before(doubledgrouppot)
label var grouppot "Group Pot"
capture drop donationshare 
gen donationshare = groupdonations / doubledgrouppot * 100
order donationshare, after(groupdonation)
label var donationshare "Group Donations, percentage"


* Balance tables for behavioral games (All students - actually more balanced if 
* we include all students as opposed to only govt perhaps because of larger sample 
* prevents small sample imbalances. 

label var q2 "Age"
label var q6 "Father education"
label var q7 "Mother education"
label var q9a "Family car ownership"
label var q9b "Family motorbike ownership"
label var q9c "Family computer ownership"
label var q9d "Family generator ownership"
label var q12new "A-levels score"
label var q13_1 "Agricultural and Environmental Sciences"
label var q13_9 "Veterinary Medicine and Animal Resources"

cd "$QJPStables"
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balancegames_lum2gov.tex if q8<5 & comp==1 & partingames==1, by(lum2) latex stars pcompare replace /// 
count armlabel(Livingstone Lumumba)
orth_out q2 q6 q7 q9* q12new q13_1-q13_10 q14_1-q14_6 q16_1-q16_14 region_* ///
using balancegames_ms2gov.tex if q8<5 & comp==1 & partingames==1, by(ms2) latex stars pcompare replace ///  
count armlabel(Africa "Mary Stuart")

* BEHAVIORAL RESULTS - GROUP LEVEL ANALYSIS

collapse (first) lum2 ms2 grouppot doubledgrouppot groupdonations donationshare ///
(mean) $controls perspocket1 offer1 perspocket2 offer2 paymentfromgrouppot totalearnings, ///
by(hallgames group)

local beh grouppot groupdonations donationshare // 
foreach var of varlist `beh' {
foreach x in lum2 ms2 {
qui eststo `var'_`x'_hall: reg `var' `x'
qui eststo `var'_`x'_ctrl: reg `var' `x' $controls
}
}

label var lum2 "Lumumba"
label var ms2 "Mary Stuart"

* Group donations regressions output with merged coeffs

foreach x in hall ctrl{
local beh grouppot groupdonations donationshare // 
foreach var of varlist `beh' {
mergemodels `var'_lum2_`x' `var'_ms2_`x'
eststo `var'_lumms_`x'
estadd local N = "`e(`var'_lum2_`x'_N)'/`e(`var'_ms2_`x'_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2_`x'_R2)'/`:di %3.2f e(`var'_ms2_`x'_R2)'"
}
}

cd "$QJPStables"
esttab grouppot_lumms_hall grouppot_lumms_ctrl groupdonations_lumms_hall ///
groupdonations_lumms_ctrl donationshare_lumms_hall donationshare_lumms_ctrl ///
using groupdonations_lumms.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) nonotes ///
star(\dag 0.10 * 0.05 ** 0.01) indicate("Controls = q2") ///
mtitles("\shortstack{Group pot\\~}" "\shortstack{Group pot\\controls}" "\shortstack{Donation\\~}" "\shortstack{Donation\\controls}" ///
"\shortstack{Donation share \\ ~}" "\shortstack{Donation share\\controls}") /// 
refcat(lum2 "", nolabel) nogaps keep(lum2 ms2) order(lum2 ms2)


