*************************************************************
** GRAPH WITH TREAT=1 FOR LUMBOX AND TREAT=0 FOR AFROSTONE **
*************************************************************


clear all

global QJPSfigures "/Users/zhaosongruan/Desktop/20045/figures"
global QJPSendline "/Users/zhaosongruan/Desktop/20045/endline"
global QJPSdofiles "/Users/zhaosongruan/Desktop/20045/do_files"

qui do "$QJPSdofiles/endline_setup.do"

* controls used in tables
global controls q2 q6 q7 q9* q12new q14_1 q14_2 region_1 region_2 region_4 
global controlsgov "q2 q6 q7 q9* q12new q14_1 q14_2 region_1 region_2 region_4 if q11==0 & q8<5"


* Code to place male and female hall coefficients side by side in (models_in1column_v2.do)
*http://www.stata.com/statalist/archive/2007-06/msg00636.html
preserve
qui do "$QJPSdofiles/models_in1column_v2.do"
restore

capture drop treat_* q34_1a100v2 q80gv2 
gen q34_1a100v2 = q34_1a100 / 100
gen q80gv2 = q80g / 2

local outcomevars q19new q38bnew q32 q34_1a100v2 q37a q64 q40new2 q79_a 
local varlabels `" "Academics (CGPA)" "Activism" "Patience (time preferences)" "Generosity (to hall)" "Interpersonal trust" "Hall identity" "Social clubs (number)" "Personality (talkative)" "' 
di `varlabels'
foreach var of varlist `outcomevars' {
	egen treat_`var' = rowtotal(lum2 ms2)
foreach x in lum ms {
	eststo `x'2_`var': reg `var' treat_`var' $controlsgov & `x'2!=., beta
}
}
local n : word count `outcomevars'
foreach x in lum ms {
forvalues i = 1/`n' {
local a : word `i' of `outcomevars'
local b : word `i' of `varlabels'
label var treat_`a' "`b'"  
}
mergemodels `x'2_q38bnew `x'2_q40new2 `x'2_q34_1a100v2 `x'2_q37a ///
`x'2_q19new `x'2_q64 `x'2_q79_a `x'2_q32 //
est sto `x'2v2_vars 
}
esttab lum2v2_vars ms2v2_vars, keep(treat*) // just to check


* FINAL coefplot with 2 headings
coefplot (lum2v2_vars), bylabel(Livingstone (0) vs. Lumumba (1)) ///
|| (ms2v2_vars), bylabel(Africa (0) vs. Mary Stuart (1)) ///
||, keep(treat_*) levels(95 90) ///
headings(treat_q38bnew = "{bf:Interpersonal outcomes}" ///
treat_q19new = "{bf:Individual outcomes}", labcolor(navy) labgap(2)) /// 
msize(medium) xline(0, lcolor(black) lpattern(dash)) /// 
xtitle("Standardized (beta) coefficients", size(medium)) coeflabels(, labgap(2) labsize(medium)) /// notick
xlabel(, labsize(medium)) ysize(2.5) byopts(iscale(*1.33))
graph play "$QJPSdofiles/coefplotwhite.grec"
graph export "$QJPSfigures/result_overview_v5.pdf", replace


*** CORRECTION FOR MULTIPLE TEST FOR OUTCOMES IN OVERVIEW GRAPH 

* Useful: https://blogs.worldbank.org/impactevaluations/overview-multiple-hypothesis-testing-commands-stata
ssc install mhtexp
ssc install rwolf

* "Standard" results, as above
esttab lum2v2_vars ms2v2_vars, p keep(treat*) star(+ 0.10 * 0.05 ** 0.01)


** Method 1. Anderson's false discovery rate and sharp q-value
* use fdr_sharpened_qvalues.do downloadable from his website

* For Lumumba-Livingstone treatment
/* enter these p-values from the results right above into the dataset generated by his do-file
0.121 0.142 0.000 0.000 0.515 0.000 0.467 0.012 
press q to finish Anderson's do file */
/* results:
bky06_qval
.105
.105
.001
.001
.234
.001
.234
.016
*/

* For Mary Stuart-Africa treatment
/* enter these p-values from the results right above into the dataset generated by his do-file
0.030 0.711 0.264 0.090 0.979 0.133 0.875 0.582
press q to finish Anderson's do file */
/* results:
bky06_qval
.316
1
.55
.45
1
.45
1
1
*/

** Method 2. Romano-Wolf
* http://ftp.iza.org/dp12845.pdf

* Male halls
set seed 1
rwolf q38bnew q40new2 q34_1a100v2 q37a q19new q64 q79_a q32 if q11==0 & q8<5 & lum2!=., indepvar(lum2) method(regress) controls($controls) reps(500)

/*
------------------------------------------------------------------------------
   Outcome Variable | Model p-value    Resample p-value    Romano-Wolf p-value
--------------------+---------------------------------------------------------
            q38bnew |    0.1245             0.1158              0.4192
            q40new2 |    0.1449             0.1677              0.4192
        q34_1a100v2 |    0.0000             0.0020              0.0040
               q37a |    0.0003             0.0020              0.0100
             q19new |    0.5163             0.5649              0.7126
                q64 |    0.0001             0.0020              0.0040
              q79_a |    0.4690             0.4311              0.7126
                q32 |    0.0136             0.0319              0.0898
------------------------------------------------------------------------------
*/


* Female halls
set seed 1
rwolf q38bnew q40new2 q34_1a100v2 q37a q19new q64 q79_a q32 if q11==0 & q8<5 & ms2!=., indepvar(ms2) method(regress) controls($controls) reps(500)

/*
------------------------------------------------------------------------------
   Outcome Variable | Model p-value    Resample p-value    Romano-Wolf p-value
--------------------+---------------------------------------------------------
            q38bnew |    0.0334             0.0938              0.3473
            q40new2 |    0.7125             0.7365              0.9721
        q34_1a100v2 |    0.2678             0.2874              0.7984
               q37a |    0.0936             0.1098              0.5729
             q19new |    0.9790             0.9741              0.9840
                q64 |    0.1373             0.2156              0.6567
              q79_a |    0.8753             0.8423              0.9840
                q32 |    0.5836             0.6128              0.9721
------------------------------------------------------------------------------
*/
