** GRAPH BAR OF REPUTATIONS

clear all
set scheme s2color 

global QJPSfigures "/Users/zhaosongruan/Desktop/20045/figures"
global QJPSendline "/Users/zhaosongruan/Desktop/20045/endline"

use "$QJPSendline/endline.dta", clear

drop if nm == 1 // behavioral game participants that we could not match to survey participants

* restrict analysis to compliers
drop if comp == 0 | comp == . 

foreach x in a b c d e {
rename q76_`x'1* q76_`x'F*
rename q76_`x'2* q76_`x'M*
}

foreach y in a b c d e {
foreach x in Fnew Mnew {
tab q76_`y'`x', gen(q76_`y'`x')
}
}

keep survey_id q1 q76_aFnew1 q76_aFnew2 q76_aFnew3 q76_aMnew1 q76_aMnew2 q76_aMnew3 ///
q76_bFnew1 q76_bFnew2 q76_bFnew3 q76_bMnew1 q76_bMnew2 q76_bMnew3 ///
q76_cFnew1 q76_cFnew2 q76_cFnew3 q76_cMnew1 q76_cMnew2 q76_cMnew3 ///
q76_dFnew1 q76_dFnew2 q76_dFnew3 q76_dMnew1 q76_dMnew2 q76_dMnew3 ///
q76_eFnew1 q76_eFnew2 q76_eFnew3 q76_eMnew1 q76_eMnew2 q76_eMnew3 

duplicates report survey_id q1
drop if survey_id == . | q1 == .

reshape long @Fnew1 @Fnew2 @Fnew3 @Mnew1 @Mnew2 @Mnew3, i(survey_id q1) j(category) str

replace category = "social" if category=="q76_a"
replace category = "political" if category=="q76_b"
replace category = "academic" if category=="q76_c"
replace category = "dress smart" if category=="q76_d"
replace category = "respectful" if category=="q76_e"

rename Mnew1 hall1_liv 
rename Mnew2 hall2_lum
rename Mnew3 hall3_mit 
rename Fnew1 hall1_afr 
rename Fnew2 hall3_com 
rename Fnew3 hall2_ms 

gen sorter = .
replace sorter = 1 if category == "social"
replace sorter = 2 if category == "political"
replace sorter = 3 if category == "academic"
replace sorter = 4 if category == "dress smart"
replace sorter = 5 if category == "respectful"

* Graph on reputations

graph bar (sum) hall1_liv hall2_lum if q1==1, title("Male halls")  outergap(*.1) ///
graphregion(color(white)) percentages over(category, gap(50) label(labsize(*1.5)) sort(sorter)) ///
legend(label(1 "Livingstone") label(2 "Lumumba") rows(1) pos(6) size(medlarge)) ///
ytitle(,size(medlarge)) name(repmale, replace)
graph bar (sum) hall1_afr hall2_ms if q1==0, title("Female halls") ///
graphregion(color(white)) percentages over(category, label(labsize(*1.5)) sort(sorter)) ///
legend(label(1 "Africa") label(2 "Mary Stuart") rows(1) pos(6) size(medlarge)) ///
ytitle(,size(medlarge)) name(repfemale, replace)
graph combine repmale repfemale, graphregion(color(white)) cols(1) // 
cd $QJPSfigures
graph export 4hallreputations.pdf, replace



** TRAITS (REPUTATION) USING ADJECTIVES (Q80) graph bar

clear all
set scheme s2color 

use "$QJPSendline/endline.dta", clear

drop if nm == 1 // behavioral game participants that we could not match to survey participants

* restrict analysis to compliers
drop if comp == 0 | comp == . 

* make q80 variables go from 0 to 4 rather than 1 to 5
foreach var of varlist q80a-q80m {
replace `var' = `var' - 1
}

* restrict analysis to Lumbox and Afrostone
keep if inlist(q26,1,3,4,5)

gen hallshort = ""
replace hallshort = "afr" if q26 == 1
replace hallshort = "liv" if q26 == 3
replace hallshort = "lum" if q26 == 4
replace hallshort = "ms" if q26 == 5

foreach j in b c d f g j  { // a e h i k l m
foreach i in afr lum liv ms {
gen q80`j'_`i' = q80`j' if hallshort == "`i'"
}
}

keep survey_id q1 q80*_*

reshape long @afr @lum @liv @ms, i(survey_id q1) j(category) str

replace category = "academic" if category=="q80a_"
replace category = "activist" if category=="q80b_"
replace category = "brave" if category=="q80c_"
replace category = "calm" if category=="q80d_"
replace category = "dignified" if category=="q80e_"
replace category = "gentle" if category=="q80f_"
replace category = "humble" if category=="q80g_"
replace category = "ladylike" if category=="q80h_"
replace category = "noisy" if category=="q80i_"
replace category = "outgoing" if category=="q80j_"
replace category = "respectful" if category=="q80k_"
replace category = "stubborn" if category=="q80l_"
replace category = "vibrant" if category=="q80m_"

gen sorter = .
replace sorter = 1 if category == "activist"
replace sorter = 2 if category == "brave"
replace sorter = 3 if category == "outgoing"

replace sorter = 4 if category == "calm"
replace sorter = 5 if category == "gentle"
replace sorter = 6 if category == "humble"

graph bar (mean) liv lum if q1==1, title("Male halls") graphregion(color(white)) ///
over(category, label(labsize(*1.6)) sort(sorter)) legend(label(1 "Livingstone") label(2 "Lumumba") ///
rows(1) pos(6) size(medlarge)) ytitle("Not at all (0) to" "extremely (5)", size(medlarge)) name(adjmale, replace)
graph bar (mean) afr ms if q1==0, title("Female halls") graphregion(color(white)) ///
over(category, label(labsize(*1.6)) sort(sorter)) legend(label(1 "Africa") label(2 "Mary Stuart") ///
rows(1) pos(6) size(medlarge)) ytitle("Not at all (0) to" "extremely (5)", size(medlarge)) name(adjfemale, replace)

graph combine adjmale adjfemale, graphregion(color(white)) cols(1) // iscale(0.6) ysize(4.5)
cd $QJPSfigures
graph export halladjectives.pdf, replace
