****************************
*** ALUMNI DATA ANALYSIS ***
*** January 20, 2017 *******
****************************

global QJPSfigures "/Users/zhaosongruan/Desktop/20045/figures"
global QJPSendline "/Users/zhaosongruan/Desktop/20045/endline"
global QJPSdofiles "/Users/zhaosongruan/Desktop/20045/do_files"
global QJPStables "/Users/zhaosongruan/Desktop/20045/tables"
global QJPSreplication "/Users/zhaosongruan/Desktop/20045"
global QJPSalumni "/Users/zhaosongruan/Desktop/20045/alumni_survey"
global esttabformatse b(%8.2f) obs se(%8.2f) ar2(%8.2f) r2(%8.2f) star(+ 0.10 * 0.05 ** 0.01)
macro dir

clear all 
set more off 

cd "$QJPSalumni"
use "alumni_final.dta"
qui do "$QJPSdofiles/models_in1column_v2.do"


* Response and compliance rates by hall among alumni (data for Table A.21)

tab hall_attach if snowball_sample==0 // first row
tab hall_attach if hall_attach == hall_reside & snowball_sample==0 // second row
* third row: second row / first row
tab hall_attach if snowball_sample==0 & govt_private==1 // fourth row
* fifth row: fourth row / first row


* drop non-compliers
drop if hall_attach != hall_reside

* drop private students
tab non_comp* if govt_private == 2
drop if govt_private==2

* drop pre-1971
* Lumumba and Africa only start running in 1970/71 and not random before then, so drop those that that began pre-1970
tab hall_attach if first_year<1971
drop if first_year<1971

* Interaction with leadership
gen lum2xlead = lum2*run_leadership
label var lum2xlead "Lumumba leadership" 
gen ms2xlead = ms2*run_leadership
label var ms2xlead "Mary Stuart leadership" 


tab birth_region, gen(birth_region)
tab ethnic_group, gen(ethnic_group)
tab father_occupn, gen(father_occupn)

/* Controls: for observed imbalances as well as birth_region, ethnic groups with 
more than 100 combined respondents and father occuptions with more than 100
respondents
*/
global controls_alum birth_year birth_region1 birth_region2 birth_region3 ///
ethnic_group3 ethnic_group6 ethnic_group7 ethnic_group8 ///
ethnic_group11 father_occupn1 father_occupn3 father_occupn4 father_occupn6 ///
enumname1-enumname11 first_college_new1-first_college_new7

* rename coz names too long
rename clubs_campus_* clubc_*
rename clubs_today_* clubt_*

**********************************************************************
** OVERVIEW GRAPH WITH TREAT=1 FOR LUMBOX AND TREAT=0 FOR AFROSTONE **
**********************************************************************

capture drop treat_* 
capture drop percent_hallv2 
gen percent_hallv2 = percent_hall / 100
local outcomevars common_cgpa actionafter_pet4 talkative sure_offer80 percent_hallv2 trust_hall identity clubt_count marryfriend_afr
local varlabels `" "Academics (CGPA)" "Activism" "Personality (talkative)" "Patience (time preferences)" "Generosity (to hall)" "Interpersonal trust" "Hall identity" "Social clubs (number)" "Marriage (to Africa Hall)" "' 
di `varlabels'
foreach var of varlist `outcomevars' {
	egen treat_`var' = rowtotal(lum2 ms2)
foreach x in lum ms {
	qui eststo `x'2_`var': reg `var' treat_`var' $controls_alum if snowball_sample==0 & `x'2!=., beta
}
}
local n : word count `outcomevars'
foreach x in lum ms {
forvalues i = 1/`n' {
local a : word `i' of `outcomevars'
local b : word `i' of `varlabels'
label var treat_`a' "`b'"  
}
mergemodels `x'2_actionafter_pet4 `x'2_clubt_count `x'2_marryfriend_afr `x'2_percent_hallv2 `x'2_trust_hall /// 
`x'2_common_cgpa `x'2_identity `x'2_talkative `x'2_sure_offer80
est sto `x'2v2_vars 
}
esttab lum2v2_vars ms2v2_vars, p keep(treat*) star(+ 0.10 * 0.05 ** 0.01)

* coefplot with 2 headings
coefplot (lum2v2_vars), bylabel(Livingstone (0) vs. Lumumba (1)) ///
|| (ms2v2_vars), bylabel(Africa (0) vs. Mary Stuart (1)) ///
||, keep(treat_*) levels(95 90) ///
headings(treat_actionafter_pet4 = "{bf:Interpersonal outcomes}" ///
treat_common_cgpa = "{bf:Individual outcomes}", labcolor(navy) labgap(2)) /// 
msize(medium) xline(0, lcolor(black) lpattern(dash)) /// 
xtitle("Standardized (beta) coefficients", size(medium)) coeflabels(, labgap(2) labsize(medium)) /// 
xlabel(, labsize(medium)) ysize(2.5) byopts(iscale(*1.33))
graph play "$QJPSdofiles/coefplotwhite.grec"
cd "$QJPSfigures"
graph export resultalum_overview_v5.pdf, replace

*** CORRECTION FOR MULTIPLE TEST FOR OUTCOMES IN OVERVIEW GRAPH ANALOGOUS TO THAT IN overviewgraph.do
ssc install mhtexp
ssc install rwolf

* "Standard" results, as above
esttab lum2v2_vars ms2v2_vars, p keep(treat*) star(+ 0.10 * 0.05 ** 0.01)

** Method 1. Anderson's false discovery rate and sharp q-value
* use fdr_sharpened_qvalues.do downloadable from his website

* For Lumumba-Livingstone treatment
/* enter these p-values from the results right above into the dataset generated by his do-file
0.039 0.635 0.317 0.011 0.931 0.238 0.018 0.106
press q to finish Anderson's do file */
/* results:
bky06_qval
.085
.57
.27
.078
.615
.27
.078
.153
*/

* For Mary Stuart-Africa treatment
/* enter these p-values from the results right above into the dataset generated by his do-file
0.474 0.078 0.488 0.126 0.166 0.137 0.551 0.860
press q to finish Anderson's do file */
/* results:
bky06_qval
bky06_qval
.498
.498
.498
.498
.498
.498
.498
.755
*/


** Method 2. Romano-Wolf
* http://ftp.iza.org/dp12845.pdf

* Male halls
set seed 1
rwolf actionafter_pet4 clubt_count percent_hallv2 trust_hall common_cgpa identity talkative sure_offer80 if snowball_sample==0 & lum2!=., indepvar(lum2) method(regress) controls($controls_alum) reps(500)

/*
------------------------------------------------------------------------------
   Outcome Variable | Model p-value    Resample p-value    Romano-Wolf p-value
--------------------+---------------------------------------------------------
   actionafter_pet4 |    0.0392             0.0339              0.2156
        clubt_count |    0.6355             0.6188              0.8942
     percent_hallv2 |    0.3175             0.3094              0.6966
         trust_hall |    0.0115             0.0180              0.0938
        common_cgpa |    0.9314             0.9501              0.9501
           identity |    0.2384             0.2635              0.6766
          talkative |    0.0188             0.0160              0.1417
       sure_offer80 |    0.1070             0.1078              0.4271
------------------------------------------------------------------------------
*/

* Female halls
set seed 1
rwolf actionafter_pet4 clubt_count percent_hallv2 trust_hall common_cgpa identity talkative sure_offer80 if snowball_sample==0 & ms2!=., indepvar(ms2) method(regress) controls($controls_alum) reps(500)

/*
------------------------------------------------------------------------------
   Outcome Variable | Model p-value    Resample p-value    Romano-Wolf p-value
--------------------+---------------------------------------------------------
   actionafter_pet4 |    0.4744             0.4970              0.9521
        clubt_count |    0.0792             0.0559              0.5090
     percent_hallv2 |    0.4888             0.5030              0.9521
         trust_hall |    0.1270             0.1597              0.6287
        common_cgpa |    0.1674             0.1996              0.6287
           identity |    0.1382             0.1657              0.6287
       sure_offer80 |    0.8598             0.8483              0.9521
          talkative |    0.5512             0.5529              0.9521
------------------------------------------------------------------------------
*/



*******************************
*** CLEAN SAMPLE - ANALYSIS ***
*******************************

*** BALANCE *** 
* It's a non-random sample, may be imbalanced, check along SEC variables 

local category balance
local x birth_year first_year educ_father birth_region1-birth_region4 /// 
ethnic_group3 ethnic_group6 ethnic_group7 ethnic_group8 ethnic_group11 ///
father_occupn1 father_occupn3 father_occupn4 father_occupn6 ///
first_college_new1-first_college_new7 enumname1-enumname9

foreach var of varlist `x' {
foreach x in lum ms {
qui eststo `var'_`x'2snow: reg `var' `x'2
qui eststo `var'_`x'2: reg `var' `x'2 if snowball_sample==0
*eststo `var'_`x'2ctrl: reg `var' `x'2 $controls_alum
}
esttab `var'*, keep(lum2 ms2) star(+ 0.10 * 0.05 ** 0.01)
}
* Note: balance w and w/out snowball VERY similar

global balancevars birth_year first_year educ_father birth_region1-birth_region4 /// 
ethnic_group3 ethnic_group6 ethnic_group7 ethnic_group8 ethnic_group11 ///
father_occupn1 father_occupn3 father_occupn4 father_occupn6 ///
first_college_new1-first_college_new7 enumname2-enumname10
desc $balancevars

preserve
label var birth_year "Year of birth"
label var first_year "Start year at Makerere"
label var educ_father "Father education"
labvarch ethnic_group*, subst("ethnic_group==" "Ethnicity: ") // ethnic_group1-ethnic_group28
labvarch birth_region*, subst("birth_region==" "Birth region: ") // birth_region1-birth_region4
labvarch father_occupn*, subst("father_occupn==" "Father occupation: ")
labvarch first_college*, subst("first_college_new==" "College: ") // first_college~1-first_college~7
label var first_college~3 "College: Engineering"
labvarch enumname*, subst("enumname==" "Interviewer: ") // enumname1-enumname11

cd "$QJPStables"

orth_out $balancevars using balance_lum2alum_all.tex, by(lum2) latex stars pcompare /// 
replace count armlabel(Livingstone Lumumba)

orth_out $balancevars using balance_lum2alum_nosnow.tex if snowball_sample==0, by(lum2) latex stars pcompare ///
replace count armlabel(Livingstone Lumumba) 

orth_out $balancevars using balance_ms2alum_all.tex, by(ms2) latex stars pcompare ///
replace count armlabel(Africa "Mary Stuart")

orth_out $balancevars using balance_ms2alum_nosnow.tex if snowball_sample==0, by(ms2) latex stars pcompare replace ///
count armlabel(Africa "Mary Stuart")
restore


*** ACADEMICS *** 

local category academics
local x common_cgpa quiet_student
foreach var of varlist `x' {
foreach x in lum ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Academics regression output with merged coeffs

foreach var of varlist common_cgpa quiet_student{
mergemodels `var'_lum2m3 `var'_ms2m3
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

cd "$QJPStables"
esttab common_cgpa_lumms3 quiet_student_lumms3 using acad_alum_lumms3.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) stats(N R2) ///
mtitles("\shortstack{Grades (CGPA)}" "\shortstack{Quiet in class}") ///
indicate("Controls = birth_year") refcat(lum2 "", nolabel) nogaps keep(lum2 ms2) order(lum2 ms2) //



*** ACTIVISM *** 

local category activism
local x action_pet4 action_demo4 action_strike4 ///
actionafter_pet4 actionafter_demo4 actionafter_strike4
foreach var of varlist `x' {
foreach x in lum  ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Activism regression output
cd "$QJPStables"
foreach x in action actionafter {
esttab `x'_pet4_lum2m3 `x'_pet4_ms2m3 `x'_demo4_lum2m3 `x'_demo4_ms2m3 ///
`x'_strike4_lum2m3 `x'_strike4_ms2m3 using `x'_alum.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Sign\\a petition}" "\shortstack{Sign\\a petition}"  ///
"\shortstack{Attend\\a demonstration}" "\shortstack{Attend\\a demonstration}" ///
"\shortstack{Join\\a strike}" "\shortstack{Join\\a strike}") ///
refcat(lum2 "", nolabel) nogaps keep(lum2 ms2) order(lum2 ms2)
}


* Activism regression output with merged coeffs

foreach var of varlist action_pet4 action_demo4 action_strike4 actionafter_pet4 actionafter_demo4 actionafter_strike4{
mergemodels `var'_lum2m3 `var'_ms2m3
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

* action and actionafter in one table
cd "$QJPStables"
esttab action_pet4_lumms3 action_demo4_lumms3 action_strike4_lumms3 ///
actionafter_pet4_lumms3 actionafter_demo4_lumms3 actionafter_strike4_lumms3 ///
using actionall_alum_lumms3.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
varlabels(, elist(ms2 \hline)) stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
mgroups("On campus" "Today", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
mtitles("\shortstack{Sign\\a petition}" "\shortstack{Attend\\a demonstration}" ///
"\shortstack{Join\\a strike}" "\shortstack{Sign\\a petition}" "\shortstack{Attend\\a demonstration}" ///
"\shortstack{Join\\a strike}") indicate("Controls = birth_year") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


*** POLITICS IDEOLOGY ***

local category politics_ideology
local x politics_makerere politics_campus politics_current
foreach var of varlist `x' {
foreach x in lum ms {
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Politics regression output with merged coeffs

foreach var of varlist politics_makerere politics_campus politics_current{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

* table
cd "$QJPStables"
esttab politics_makerere_lumms3 politics_campus_lumms3 politics_current_lumms3 ///
using politics_alum_lumms3.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
varlabels(, elist(ms2 \hline)) stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
mgroups("On campus" "Today", pattern(1 0 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
mtitles("\shortstack{Makerere\\politics}" "\shortstack{Ugandan\\politics}" ///
"\shortstack{Ugandan\\politics}") indicate("Controls = birth_year") ///
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


*** CLUBS ON CAMPUS AND TODAY ***

local category clubs
local x clubc_political clubt_political clubc_count clubt_count
foreach var of varlist `x' {
foreach x in lum  ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Clubs regression output with merged coeffs

foreach var of varlist clubc_political clubt_political clubc_count clubt_count{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

*** SOCIAL ***

local category social
local x hall_soc_events hall_sports
foreach var of varlist `x' {
foreach x in lum  ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}


* Social regression output with merged coeffs

foreach var of varlist hall_soc_events hall_sports{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

* Clubs and social events
cd "$QJPStables"
esttab hall_soc_events_lumms3 hall_sports_lumms3 ///
clubc_political_lumms3 clubc_count_lumms3 clubt_political_lumms3 clubt_count_lumms3 ///
using cluball_alum_lumms3.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mgroups("On campus" "Today", pattern(1 0 0 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
mtitles("\shortstack{Social\\events}" "\shortstack{Campus\\sports}" ///
"\shortstack{Member of a\\political club}" "\shortstack{Number\\of clubs}" /// 
"\shortstack{Member of a\\political club}" "\shortstack{Number\\of clubs}") ///
indicate("Controls = birth_year") nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


*** DATING AND MARRIAGE ***
estimates clear
local category dating
local x friend_hall_afr friend_hall_liv friend_hall_lum friend_hall_ms ///
marryfriend_afr marryfriend_liv marryfriend_lum marryfriend_ms 
foreach var of varlist `x' {
foreach x in lum ms {
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Dating and marriage regressions
cd "$QJPStables"
esttab friend_hall_afr_lum2m3 friend_hall_ms_lum2m3 marryfriend_afr_lum2m3 marryfriend_ms_lum2m3 ///
using datemarry_lum2alum.tex, replace label varlabels(, elist(lum2 \hline)) ///
stats(N r2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Dating\\Africa resident}" "\shortstack{Dating\\Mary Stuart resident}" ///
"\shortstack{Marrying\\Africa resident}" "\shortstack{Marrying\\Mary Stuart resident}") /// 
indicate("Controls = birth_year") nogaps keep(lum2) order(lum2) // refcat(lum2 "", nolabel) 


cd "$QJPStables"
esttab friend_hall_liv_ms2m3 friend_hall_lum_ms2m3 marryfriend_liv_ms2m3 marryfriend_lum_ms2m3 ///
using datemarry_ms2alum.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Dating\\Livingstone resident}" "\shortstack{Dating\\Lumumba resident}" ///
"\shortstack{Marrying\\Livingstone resident}" "\shortstack{Marrying\\Lumumba resident}") /// 
refcat(ms2 "", nolabel) nogaps keep(ms2) order(ms2)


*** IMPATIENCE *** 

** Recode 0 now vs. 1 later so that beta>0 is more patient!

local category econ_career
local x sure_offer80 sure_offer100 identity
foreach var of varlist `x' {
foreach x in lum ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 log_income $controls_alum , cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 log_income $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 log_income $controls_alum if snowball_sample==0, cluster(source_num)
} 
}


* Hall ID and time preferences regressions output with merged coeffs

foreach var of varlist sure_offer80 sure_offer100 identity{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

cd "$QJPStables"
esttab identity_lumms3 sure_offer80_lumms3 sure_offer100_lumms3 ///
using identity_timedisc_alum_lumms3.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
varlabels(, elist(ms2 \hline)) stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) ///
mtitles("\shortstack{Hall identity}" "\shortstack{Now vs. in 1 week}" "\shortstack{Now vs. in 1 month}") /// 
indicate("Controls = birth_year") nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


*** TRUST AND PSYCH *** 

rename calm_always alwayscalm
local category trust_psych
local x trust_hall log_trust_loan ///
talkative clever disorganized alwayscalm cooperative /// 
activist brave calm humble outgoing respectful percent_hall
foreach var of varlist `x' {
foreach x in lum  ms { 
qui eststo `var'_`x'2m1: reg `var' `x'2 $controls_alum, cluster(source_num)
qui eststo `var'_`x'2m2: reg `var' `x'2 $controls_alum if snowball_sample==0
qui eststo `var'_`x'2m3: reg `var' `x'2 $controls_alum if snowball_sample==0, cluster(source_num)
}
}

* Trust regressions output with merged coeffs

foreach var of varlist trust_hall log_trust_loan percent_hall{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

cd "$QJPStables"
esttab trust_hall_lumms3 log_trust_loan_lumms3 percent_hall_lumms3 ///
using trust_alum_lumms3.tex, replace label varlabels(, elist(ms2 \hline)) ///
stats(N R2, fmt(0 2) labels("N" "\(R^{2}\)")) b(2) se(2) r2(2) ///
nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Hallmates would\\give you a fair deal}" ///
"\shortstack{Would loan to\\hallmates}" ///
"\shortstack{Hall allocation}") indicate("Controls = birth_year") /// 
nogaps keep(lum2 ms2) order(lum2 ms2) // refcat(lum2 "", nolabel) 


* Regressions on traits: OCEAN
cd "$QJPStables"
foreach var of varlist lum2 ms2 {
esttab talkative_`var'm3 clever_`var'm3 disorganized_`var'm3 alwayscalm_`var'm3 ///
cooperative_`var'm3 using ocean_`var'alum.tex, replace label ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Talkative}" "\shortstack{Clever}"  ///
"\shortstack{Disorganized}" "\shortstack{Alwayscalm}" ///
"\shortstack{Cooperative}") ///
refcat(`var' "", nolabel) nogaps keep(`var') order(`var')
}


* Regressions on traits: OCEAN output with merged coeffs
* talkative (Extraversion) clever (Openness to experience) 
* disorganized (Conscientousness) alwayscalm (Neuroticism) cooperative (Agreeableness)

foreach var of varlist talkative clever disorganized alwayscalm cooperative{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

cd "$QJPStables"
esttab talkative_lumms3 clever_lumms3 disorganized_lumms3 ///
alwayscalm_lumms3 cooperative_lumms3 using ocean_alum_lumms3.tex, ///
replace label stats(N R2) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Talkative}" "\shortstack{Clever}"  ///
"\shortstack{Disorganized}" "\shortstack{Alwayscalm}" ///
"\shortstack{Cooperative}") ///
indicate("Controls = birth_year") refcat(lum2 "", nolabel) nogaps keep(lum2 ms2) order(lum2 ms2)


* Regressions on traits: Adjectives output with merged coeffs

foreach var of varlist activist brave calm humble outgoing respectful{
mergemodels `var'_lum2m3 `var'_ms2m3 
eststo `var'_lumms3
estadd local N = "`e(`var'_lum2m3_N)'/`e(`var'_ms2m3_N)'"
estadd local R2 = "`:di %3.2f e(`var'_lum2m3_R2)'/`:di %3.2f e(`var'_ms2m3_R2)'"
}

cd "$QJPStables"
esttab activist_lumms3 brave_lumms3 calm_lumms3 humble_lumms3 ///
outgoing_lumms3 respectful_lumms3 using adjectives_alum_lumms3.tex, ///
replace label stats(N R2) ///
b(2) se(2) r2(2) nonotes star(\dag 0.10 * 0.05 ** 0.01) ///
mtitles("\shortstack{Activist}" "\shortstack{Brave}"  ///
"\shortstack{Calm}" "\shortstack{Humble}" ///
"\shortstack{Outgoing}" "\shortstack{Respectful}" ) ///
indicate("Controls = birth_year") refcat(lum2 "", nolabel) nogaps keep(lum2 ms2) order(lum2 ms2)

